@@ -1,5 +1,4 @@
 import subprocess
-import time
 
 
 class FailedToSynchronize(Exception):
@@ -9,7 +8,6 @@ class FailedToSynchronize(Exception):
 def main(*args):
     config_path = args[0]
 
-    started = time.time()
     cmd = [
         'task',
         'rc:%s' % config_path,
@@ -24,8 +22,5 @@ def main(*args):
     _, stderr = proc.communicate()
     if proc.returncode != 0:
         raise FailedToSynchronize(stderr)
-    finished = time.time()
 
-    total_duration = finished - started
-
-    return "Sync Successful", "%s" % total_duration
+    return "Sync Successful"
